package com.cool.bang.modules.mysql.domain;

import com.cool.bang.modules.oracle.domain.po.BhtTrade;
import com.cool.bang.modules.oracle.domain.po.HtPay;
import org.springframework.util.StringUtils;

import java.math.BigDecimal;
import java.util.List;


public class Fund {


    /**
     * 通知书编号
     */
    private String businessNumber;

    /**
     * 银行编码
     */
    private String bankCode;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 合同编号
     */
    private String contractNumber;

    /**
     * 交存款项 1首期款（含一次性付款）2分期后期款 3商业贷款 4公积金贷款
     */
    private Integer paymentType;

    /**
     * 应交存金额
     */
    private BigDecimal payableAmount;

    /**
     * 已交存金额
     */
    private BigDecimal paidAmount;

    /**
     * 待交存金额
     */
    private BigDecimal unpaidAmount;

    /**
     * 收款银行
     */
    private String collectionBank;

    /**
     * 收款户名
     */
    private String collectionName;

    /**
     * 收款账号
     */
    private String collectionAccount;

    /**
     * 收款开户网点
     */
    private String collectionOpenAddress;

    /**
     * 账户类型 1托管账户 2监管账户
     */
    private Integer accountType;

    /**
     * 交存通知书文件路径
     */
    private String pdfUrl;

    /**
     * 交存状态 0未交存 1未足额 2已交存
     */
    private Integer paymentStatus;

    /**
     * 是否撤销 0未撤销 1撤销
     */
    private Integer isRescind;

    /**
     * 删除标识 1正常 0删除
     */
    private Integer delFlag;


    public Fund(Account account, HtPay htPay, Long newContractId, List<BhtTrade> bhtTrades) {
        this.businessNumber = htPay.getJKBH();
        if (null != account) {
            this.collectionBank = account.getBankName();
            this.collectionName = account.getName();
            this.collectionAccount = account.getAccount();
            this.collectionOpenAddress = account.getOpenAddress();
            this.accountType = account.getType();
            this.bankCode = account.getBankCode();
        }
        this.contractId = newContractId;
        this.contractNumber = htPay.getHTBH();
        //1首期款，2商业贷款，3公积金贷款  4其它付款   12 第二期付款 13 第 三期  14第四期  15第五期
        this.paymentType = getToPaymentType(htPay.getPAYTYPE());
        this.payableAmount = htPay.getJKJE();
        if (null == bhtTrades && bhtTrades.isEmpty()) {
            this.paidAmount = BigDecimal.ZERO;
        } else {
            //单条的
            if (bhtTrades.size() == 1) {
                BhtTrade item = bhtTrades.get(0);
                //如果是ZJJGFLAG = 0
                if ("0".equals(item.getZJJGFLAG())) {
                    //小于等于通知书jkje 已交 直接赋值
                    if (item.getTradeAmount().compareTo(htPay.getJKJE()) < 1) {
                        this.paidAmount = item.getTradeAmount();
                    } else {
                        //大于通知书金额  已交 设置为0
                        this.paidAmount = BigDecimal.ZERO;
                    }
                } else {
                    //ZJJGFLAG = 1的
                    this.paidAmount = item.getTradeAmount();
                }
            } else {
                //多条的
                BigDecimal zjjIsOne = BigDecimal.ZERO;
                BigDecimal dJ = BigDecimal.ZERO;
                BigDecimal zjjIsZero = BigDecimal.ZERO;
                for (BhtTrade item : bhtTrades) {
                    //定金
                    if (9 == item.getPayType()) {
                        dJ = dJ.add(item.getTradeAmount());
                    }
                    if (1 == item.getPayType() && "1".equals(item.getZJJGFLAG())) {
                        zjjIsOne = zjjIsOne.add(item.getTradeAmount());
                    }
                    if (1 == item.getPayType() && "0".equals(item.getZJJGFLAG())) {
                        zjjIsZero = zjjIsZero.add(item.getTradeAmount());
                    }
                }
                //为1 的 等于jkje
                if (zjjIsOne.compareTo(htPay.getJKJE()) == 0) {
                    this.paidAmount = zjjIsOne;
                }
                //为0 的等于jkje
                else if (zjjIsZero.compareTo(htPay.getJKJE()) == 0) {
                    this.paidAmount = zjjIsZero;
                }
                //为1的加上定金 等于的
                else if (zjjIsOne.add(dJ).compareTo(htPay.getJKJE()) == 0) {
                    this.paidAmount = zjjIsOne.add(dJ);
                }
                //为0 的加上定金 等于
                else if (zjjIsZero.add(dJ).compareTo(htPay.getJKJE()) == 0) {
                    this.paidAmount = zjjIsZero.add(dJ);
                }
                //如果为0  为1 的加起来等于 jkje
                else if (zjjIsOne.add(zjjIsZero).compareTo(htPay.getJKJE()) == 0) {
                    this.paidAmount = zjjIsOne.add(zjjIsZero);
                }
                //为0 为1 的 加上定金 等于 JKJE
                else if (zjjIsOne.add(zjjIsZero.add(dJ)).compareTo(htPay.getJKJE()) == 0) {
                    this.paidAmount = zjjIsOne.add(zjjIsZero.add(dJ));
                }
                //为0 的 大于jkje  直接  已交为0
                else if (zjjIsZero.compareTo(htPay.getJKJE()) == 1) {
                    this.paidAmount = BigDecimal.ZERO;
                } else {
                    this.paidAmount = BigDecimal.ZERO;
                }
            }
        }
        this.unpaidAmount = this.payableAmount.subtract(this.paidAmount);

        //如果实际交款金额大于 应缴  把实际交款变成应交
        if (this.paidAmount.compareTo(this.payableAmount) == 1) {
            this.paidAmount = this.payableAmount;
        }
        //如果通知书金额为0
        if(BigDecimal.ZERO.compareTo(this.payableAmount) == 0){
            this.paymentStatus = 0;//待交存
            //应交  = 已交
        } else if (this.payableAmount.compareTo(this.paidAmount) == 0) {
            this.paymentStatus = 2;//已交存
        } else if (this.payableAmount.compareTo(this.unpaidAmount) == 0) {
            this.paymentStatus = 0;//待交存
        } else if (this.paidAmount.compareTo(this.payableAmount) == -1) {
            this.paymentStatus = 1;//未足额
        }
        //默认是未撤销
        this.isRescind = 0;
        this.delFlag = 1;
    }

    private Integer getToPaymentType(String paytype) {
        switch (paytype) {
            case "1"://首期款
                return 1;//(包含一次性付款)
            case "2"://商业贷款
                return 3;
            case "3"://公积金贷款
                return 4;
            case "4"://其他付款
                return 1;
            default://分期
                return 2;
        }
    }


    public String getBusinessNumber() {
        return businessNumber;
    }

    public void setBusinessNumber(String businessNumber) {
        this.businessNumber = businessNumber;
    }

    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractNumber() {
        return contractNumber;
    }

    public void setContractNumber(String contractNumber) {
        this.contractNumber = contractNumber;
    }

    public Integer getPaymentType() {
        return paymentType;
    }

    public void setPaymentType(Integer paymentType) {
        this.paymentType = paymentType;
    }

    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }

    public BigDecimal getPaidAmount() {
        return paidAmount;
    }

    public void setPaidAmount(BigDecimal paidAmount) {
        this.paidAmount = paidAmount;
    }

    public BigDecimal getUnpaidAmount() {
        return unpaidAmount;
    }

    public void setUnpaidAmount(BigDecimal unpaidAmount) {
        this.unpaidAmount = unpaidAmount;
    }

    public String getCollectionBank() {
        return collectionBank;
    }

    public void setCollectionBank(String collectionBank) {
        this.collectionBank = collectionBank;
    }

    public String getCollectionName() {
        return collectionName;
    }

    public void setCollectionName(String collectionName) {
        this.collectionName = collectionName;
    }

    public String getCollectionAccount() {
        return collectionAccount;
    }

    public void setCollectionAccount(String collectionAccount) {
        this.collectionAccount = collectionAccount;
    }

    public String getCollectionOpenAddress() {
        return collectionOpenAddress;
    }

    public void setCollectionOpenAddress(String collectionOpenAddress) {
        this.collectionOpenAddress = collectionOpenAddress;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public String getPdfUrl() {
        return pdfUrl;
    }

    public void setPdfUrl(String pdfUrl) {
        this.pdfUrl = pdfUrl;
    }

    public Integer getPaymentStatus() {
        return paymentStatus;
    }

    public void setPaymentStatus(Integer paymentStatus) {
        this.paymentStatus = paymentStatus;
    }

    public Integer getIsRescind() {
        return isRescind;
    }

    public void setIsRescind(Integer isRescind) {
        this.isRescind = isRescind;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }
}
