package com.cool.bang.modules.mysql.mapper;

import com.cool.bang.modules.mysql.domain.OrgAccount;
import com.cool.bang.modules.mysql.domain.*;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Repository
public interface MySqlMapper {

    /**
     * 插入监管开户申请业务表数据
     *
     * @param superviseBusinessList
     * @return
     */
    int insertSuperviseBusiness(@Param("list") List<SuperviseBusiness> superviseBusinessList);

    int insertSuperviseRelieve(SuperviseRelieve superviseRelieve);

    int insertSuperviseTo(SuperviseTo superviseTo);

    int insertSuperviseToDetail(@Param("list") List<SuperviseToDetail> superviseToDetailList);

    int insertSuperviseToPosting(@Param("list") List<SuperviseToPosting> superviseToPostingList);

    int insertSuperviseToOutgoing(@Param("list") List<SuperviseToOutgoing> superviseToOutgoingList);

    int insertProgress(Progress progress);

    int insertProgressDetail(@Param("list") List<ProgressDetail> progressDetailList);

    int insertBatchContractOverdue(@Param("list") List<ContractOverdue> list);

    int insertAppropriation(Appropriation appropriation);

    int insertAppropriationDetail(@Param("list") List<AppropriationDetail> appropriationDetails);

    int insertAppropriationOutgoing(AppropriationOutgoing outgoing);

    int insertAppropriationPosting(AppropriationPosting posting);

    int insertRelieve(Relieve relieve);

    /**
     * 更新楼幢字符串
     */
    int updateRelieveBuilding(@Param("id") Long id, @Param("relieveBuilding") String relieveBuilding);

    int insertRelieveDetail(@Param("list") List<RelieveDetail> relieveDetailList);

    int insertContract(@Param("list") List<Contract> contracts);

    int insertFund(@Param("list") List<Fund> funds);

    //根据 合同编号查询合同id
    Long getContractIdByNumber(@Param("htbh") String htbh);

    int insertEarnest(@Param("list") List<Earnest> earnests);

    int insertRefund(Refund refund);

    ContractInfo getInfoByNumber(@Param("htBh") String htBh);

    int insertFcTrade(@Param("list") List<FcTrade> fcTrades);

    /**
     * 查询正常的 托管项目
     *
     * @return
     */
    List<Map<String, Object>> selectTgXm();

    /**
     * 根据项目id 查询项目虚拟户
     *
     * @param
     * @return
     */
    List<Map<String, Object>> selectXmAccountByProjectId(@Param("projectId") Long projectId);

    List<Map<String, Object>> selectBuildingBy(@Param("projectId") Long id, @Param("projectAccountId") Long projectAccountId);

    BigDecimal getAccountBalanceByNumber(@Param("buildingNumber") String buildingNumber);

    /**
     * 更新 building_account
     *
     * @param lzbh
     * @param
     * @param
     * @return
     */
    int updateBuildingAccountByLZBH(@Param("lzbh") String lzbh, @Param("name") String name, @Param("id") int id);

    /**
     * 查询八个托管账户的信息
     *
     * @return
     */
    List<Account> selectTgAccountInfo();

    /**
     * 查询每个托管账户下的项目
     *
     * @return
     */
    List<ProjectAccount> selectTgProjectAccountInfo(String bankCode);

    /**
     * 更新楼幢账户表额度内余额
     */
    int updateInLimitFund();

    /**
     * 更新楼幢账户表主键
     */
    int updateBuildingAccountId();

    /**
     * 银行流水编号
     *
     * @param serialNumbers
     * @return
     */
    List<Account> selectTsDzByserial(@Param("serialNumbers") List<String> serialNumbers);

    /**
     * 获取托管账户的交存
     *
     * @return
     */
    List<FundInfo> getTgFund();

    /**
     * 根据业务编号查询 交易 金额
     *
     * @param businessNumber
     * @return
     */
    BigDecimal getAmountByBusinessNumber(@Param("businessNumber") String businessNumber);

    /**
     * 获取projectAccountId
     *
     * @param aregId
     * @return
     */
    Long getProjectAccountIdByAregId(@Param("aregId") Integer aregId);

    /**
     * 查询银行账单
     */
    List<BankBill> selectByBankBill(@Param("bankCode") String bankCode,
                                    @Param("startDate") String startDate,
                                    @Param("endDate") String endDate);

    /**
     * 根据账户查询交易总余额
     */
    List<BankBill> selectAccountBill(String account);


    List<OrgAccount> selectOrgList();

    //-------------- 查询 ------------------

    List<ProjectAccountTrade> selectPaymentTrade();

    List<ProjectAccountTrade> selectAppropriationTrade();

    List<ProjectAccountTrade> selectProjectAccount();

    // 更新p_lpb_xmxx 状态
    int updateProjectStatus();

    /**
     * 获取逾期合同
     *
     * @return
     */
    ContractOverdue getOverdueContractInfo(@Param("contractNumber") String contractNumber);


    /**
     * 校验这些 逾期的合同 是否有已经解除楼栋 的 或者是 贷款已经放款的
     * @param contractNumber
     * @return
     */
    ContractOverdue checkOverdueContractIsRealOverdue(@Param("contractNumber") String contractNumber);

    /**
     * 获取 交存状态为首次已交存 的合同 并且没有首次交存时间的
     * @return
     */
    List<Contract> getContractBySqyjc();

    /**
     * 更新 合同首期款交存时间
     * @param data
     */
    int updatePaymeTime(@Param("params") List<Contract> data);

    /**
     * 获取 2022年07月之前的合同 处理交存状态为 1 但是贷款已经放款了的 老的合同  变为状态 为交存完成
     * @return
     */
    List<Contract> getOldContract();

    Integer checkSdJcByContractId(@Param("contractId") Long contractId);

    Integer checkGjjJcByContractId(@Param("contractId") Long contractId);

    void updatPaymentStatus(@Param("params") List<Contract> oldContract);

    /**
     * 更新所有的合同逾期状态为 0  正常
     */
    void updateContractSetOverdue();

    /**
     * 查询首期交存时间
     * @param id
     * @return
     */
    Date getFundTradeByContractId(@Param("id") Long id);

    /**
     * 查询 fund del_flag = 0
     * 并且  payment_type = 1
     * payment_status > 0
     * @return
     */
    List<Map<String,Object>>  getFundDelflag_0();

    /**
     * 更新合同免存状态
     * @param numbers
     */
    void updateIsExempt(@Param("params")List<Long> numbers);
}
