package com.cool.bang.modules.mysql.service;

import com.cool.bang.modules.mysql.domain.Account;
import com.cool.bang.modules.mysql.domain.Org;
import com.cool.bang.modules.mysql.domain.Project;
import com.cool.bang.modules.mysql.mapper.AccountMapper;
import com.cool.bang.modules.mysql.mapper.OrgMapper;
import com.cool.bang.modules.mysql.mapper.ProjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 账户导入
 *
 * @author PeiZhi Guo
 * 2023-3-7 11:27
 */
@Service
public class AccountService extends BaseService {

    public void execute() {
        long startTime = System.currentTimeMillis();
        System.out.println(">>>>>>>>>>>>>>>>>>" + "导入账户开始执行，" + startTime);

        List<Map<String,Object>> list = oracleMapper.selectFromAccount();
        List<Account> accountList = new ArrayList<>();

        System.out.println(">>>>>>>>>>>>>>>>>>" + "导入条数：" + list.size() + "条");

        for (Map<String, Object> map : list) {
            Account account = new Account(map);
            BigDecimal id = (BigDecimal) map.get("ACCOUNTID");
            account.setId(id.longValue());
            if (map.get("QYBH") != null) {
                Org org = orgMapper.selectOrgByMisid(Integer.parseInt(map.get("QYBH").toString().trim()));
                account.setOrgId(org.getId());
                account.setOrgName(org.getOrgName());
                account.setName(org.getOrgName());
            }
            if (map.get("XMBH") != null) {
                Project project = projectMapper.selectByProjectNumber((String) map.get("XMBH"));
                if (project != null) {
                    account.setProjectId(project.getId());
                    account.setProjectName(project.getProjectName());
                    account.setProjectNumber(project.getProjectNumber());
                }
            }
            //查询账户在途资金
            BigDecimal inTransitFund = oracleMapper.selectAccountInTransitFund(Integer.parseInt(map.get("ACCOUNTID").toString()));
            if (inTransitFund != null){
                account.setInTransitFund(inTransitFund);
            }
            accountList.add(account);
        }
        int i = accountMapper.insertAccount(accountList);

        // 查询账号的数据
        List<Long> ids = accountMapper.selectReuseAcoount();
        for (Long id : ids) {
            accountMapper.deleteById(id);
        }
        System.out.println(">>>>>>>>>>>>>>>>>>导入账户结束，插入"+ i +"条数据，执行时间："
                + (System.currentTimeMillis() - startTime) + "ms");
    }
}
